==> geant4.9.5.p02.tar.gz: geant4.9.5.p02/examples/extended/analysis/A01/src/A01MagneticField.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: A01MagneticField.cc,v 1.7 2009-11-21 00:22:55 perl Exp $
// --------------------------------------------------------------
//

#include "A01MagneticField.hh"
#include "A01MagneticFieldMessenger.hh"
#include "globals.hh"

A01MagneticField::A01MagneticField()
{
  messenger = new A01MagneticFieldMessenger(this);
  By = 1.0*tesla;
  
}

A01MagneticField::~A01MagneticField()
{ delete messenger; }

void A01MagneticField::GetFieldValue(const G4double [4],double *Bfield) const
{
  Bfield[0] = 0.;
  Bfield[2] = 0.;
  Bfield[1] = By;

}

==> geant4.9.6.p03.tar.gz: geant4.9.6.p03/examples/extended/analysis/A01/src/A01MagneticField.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file analysis/A01/src/A01MagneticField.cc
/// \brief Implementation of the A01MagneticField class
//
// $Id$
// --------------------------------------------------------------
//

#include "A01MagneticField.hh"
#include "A01MagneticFieldMessenger.hh"
#include "G4SystemOfUnits.hh"
#include "globals.hh"

A01MagneticField::A01MagneticField()
{
  fMessenger = new A01MagneticFieldMessenger(this);
  fBy = 1.0*tesla;
  
}

A01MagneticField::~A01MagneticField()
{ delete fMessenger; }

void A01MagneticField::GetFieldValue(const G4double [4],double *Bfield) const
{
  Bfield[0] = 0.;
  Bfield[2] = 0.;
  Bfield[1] = fBy;

}
